@@ -1,5 +1,21 @@
 import copy
+import os
+import re
 from typing import Dict
+from typing import List
+
+import numpy as np
+
+
+__all__ = [
+    'get_tpu_devices',
+    'STR_TO_DTYPE',
+    'to_raw',
+]
+
+
+def get_tpu_devices() -> List[str]:
+    return [os.path.join('/dev', f) for f in os.listdir('/dev') if re.match(r'tpu.', f) and len(f) == 4]
 
 
 def to_raw(metadata: Dict) -> Dict:
@@ -23,3 +39,10 @@ def to_raw(metadata: Dict) -> Dict:
                 [[0, 0], ] * len(raw_metadata['outputs'][idx][name]['tpu_shape'])
 
     return raw_metadata
+
+
+STR_TO_DTYPE = {
+    'int8': np.int8,
+    'float16': np.float16,
+    'float32': np.float32,
+}
